@@ -15,7 +15,7 @@
 #
 # END HEADER
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
 from hypothesis.errors import FailedHealthCheck
 
@@ -27,12 +27,10 @@ def fail_health_check(settings, message, label):
 
     if label in settings.suppress_health_check:
         return
-    if not settings.perform_health_check:
-        return
     message += (
-        '\nSee https://hypothesis.readthedocs.io/en/latest/health'
-        'checks.html for more information about this. '
-        'If you want to disable just this health check, add %s '
-        'to the suppress_health_check settings for this test.'
+        "\nSee https://hypothesis.readthedocs.io/en/latest/health"
+        "checks.html for more information about this. "
+        "If you want to disable just this health check, add %s "
+        "to the suppress_health_check settings for this test."
     ) % (label,)
     raise FailedHealthCheck(message, label)
